#!/bin/sh
#
# Start stop script for TORQUE
#
# Authors : Bas van der Vlies & Jaap Dijkshoorn
#	    Kilian Cavalotti
#
# SVN INFO:
#       $Id: init.d 1225 2005-06-21 14:38:47Z bas $
#
#set -x
DESC="TORQUE servers"
TORQUE_DIR=/usr/sbin
DEFAULT=/etc/default/torque

# Some useful defaults can be overriden in the DEFAULT file
#
PBS_MOM_OPTS=''
PBS_SCHED_OPTS=''
PBS_SERVER_OPTS='-a t'

if [ ! -f $DEFAULT ]
then
        echo "No file [$DEFAULT]"
	exit 0
fi
. $DEFAULT

## Start functions
start_server() {
        start-stop-daemon --start --quiet --exec $TORQUE_DIR/pbs_server -- $PBS_SERVER_OPTS
        echo " pbs server"
}

start_sched() {
	start-stop-daemon --start --quiet --exec $TORQUE_DIR/pbs_sched -- $PBS_SCHED_OPTS
	echo " pbs sched"
}

start_mom() {
	start-stop-daemon --start --quiet --exec $TORQUE_DIR/pbs_mom -- $PBS_MOM_OPTS
	echo " pbs mom"
}

start_servers() {
	if [ "$PBS_SERVER" = "1" ]
	then
		start_server
	fi

	if [ "$PBS_SCHED" = "1" ]
	then
		start_sched
	fi

	if [ "$PBS_MOM" = "1" ]
	then
		start_mom
	fi
}

## Stop functions

stop_server() {
        start-stop-daemon --retry 5 --stop --quiet --exec $TORQUE_DIR/pbs_server
        echo " pbs server"
	echo " waiting for server to shutdown"
	sleep 5
}

stop_sched() {
	start-stop-daemon --retry 5 --stop --quiet --exec $TORQUE_DIR/pbs_sched
	echo " pbs sched"
}

stop_mom() {
	start-stop-daemon --retry 5 --stop --quiet --exec $TORQUE_DIR/pbs_mom
	echo " pbs mom"
}

stop_servers() {
	if [ "$PBS_SERVER" = "1" ]
	then
		stop_server
	fi

	if [ "$PBS_SCHED" = "1" ]
	then
		stop_sched
	fi

	if [ "$PBS_MOM" = "1" ]
	then
		stop_mom
	fi
}


## Main
case "$1" in
        start)
                echo "Starting $DESC: "
                start_servers
        ;;

        stop)
                echo "Stopping $DESC: "
                stop_servers
        ;;

        restart)
                echo "Restarting $DESC: "
                stop_servers
                sleep 1
                start_servers
        ;;

        *)
                echo "Usage: $0 {start|stop|restart}\n" >&2
                exit 1
        ;;
esac

exit 0

